## Repository setup
- [ ] Begin USAGE wiki
- [ ] Begin INSTALL wiki
- [ ] Begin Output wiki
- [ ] Build pypi package
- [ ] Build conda package
- [x] Update intro page
- [ ] Add issue format
- [ ] Mirror with GitHub
- [ ] Annotate code

## Algorithm improvements
- [ ] Account for tandem dup HGs
- [ ] Tune hyperparameters for global maximum quality output
	- [ ] High percentage of 1 domain/reference cluster
- [ ] Convert sliding window to nucleotide-based slide
- [ ] Account for alternate splicing appropriately
- [ ] Implement probabilistic pass for 2 HG HG combinations
- [ ] Account for duplicates of HGs on edge of cluster
- [ ] Add Pfam extraction feature
- [ ] Add GO extraction feature
- [ ] Output networks as interactable files
